@@ -96,7 +96,7 @@ class CfnCluster(
             tags=tags,
         )
 
-        jsii.create(CfnCluster, self, [scope, id, props])
+        jsii.create(self.__class__, self, [scope, id, props])
 
     @jsii.member(jsii_name="inspect")
     def inspect(self, inspector: aws_cdk.core.TreeInspector) -> None:
@@ -653,7 +653,7 @@ class CfnParameterGroup(
             parameter_name_values=parameter_name_values,
         )
 
-        jsii.create(CfnParameterGroup, self, [scope, id, props])
+        jsii.create(self.__class__, self, [scope, id, props])
 
     @jsii.member(jsii_name="inspect")
     def inspect(self, inspector: aws_cdk.core.TreeInspector) -> None:
@@ -831,7 +831,7 @@ class CfnSubnetGroup(
             subnet_group_name=subnet_group_name,
         )
 
-        jsii.create(CfnSubnetGroup, self, [scope, id, props])
+        jsii.create(self.__class__, self, [scope, id, props])
 
     @jsii.member(jsii_name="inspect")
     def inspect(self, inspector: aws_cdk.core.TreeInspector) -> None:
